API Reference
=============

This section contains the complete API documentation for all modules in COASTSim.

Core Modules
------------

.. toctree::
   :maxdepth: 2

   conops.config
   conops.config.acs
   conops.config.communications
   conops.config.data_generator
   conops.config.fault_management
   conops.config.observation_categories
   conops.config.power
   conops.config.spacecraft_bus
   conops.config.thermal
   conops.ditl
   conops.ditl.ditl
   conops.ditl.ditl_event
   conops.ditl.ditl_log
   conops.ditl.ditl_log_store
   conops.ditl.ditl_mixin
   conops.ditl.ditl_stats
   conops.ditl.queue_ditl
   conops.simulation
   conops.simulation.acs
   conops.simulation.acs_command
   conops.simulation.roll

Scheduling and Planning
-----------------------

.. toctree::
   :maxdepth: 2

   conops.schedulers
   conops.schedulers.scheduler
   conops.schedulers.queue_scheduler
   conops.targets
   conops.targets.pointing
   conops.targets.plan
   conops.targets.plan_entry
   conops.targets.target_queue

Spacecraft Components
---------------------

.. toctree::
   :maxdepth: 2

   conops.battery
   conops.solar_panel
   conops.instrument
   conops.recorder

Orbit and Pointing
------------------

.. toctree::
   :maxdepth: 2

   conops.ephemeris
   conops.slew
   conops.vector

Constraints and Environment
---------------------------

.. toctree::
   :maxdepth: 2

   conops.constraint
   conops.saa
   conops.emergency_charging

Ground Support
--------------

.. toctree::
   :maxdepth: 2

   conops.groundstation
   conops.passes

Utilities
---------

.. toctree::
   :maxdepth: 2

   conops.common
   conops.common.enums
   conops.constants

Visualization
-------------

.. toctree::
   :maxdepth: 2

   conops.visualization
